/** 
 * TTF font dumper program.
 * It dumps available glyphs in a True Type font.
 *  GNU Copyright (C) 2002  Gaspar Sinai <gsinai@yudit.org>  
 */

#include "stoolkit/SIO.h"
#include "stoolkit/SEncoder.h"
#include "swindow/SFontTTF.h"

#include <stdio.h>
#include <string.h>
#include <stdlib.h>


static void usage ();

/**
 *  This is a very simple program.
 */
int
main (int argc, char* argv[])
{
  
  if (argc != 2)
  {
    usage ();
    return (1);
  }
  
  SFile file (argv[1]);
  if (file.size() < 0)
  {
    fprintf (stderr, "ttfdump: can not read '%s'\n", argv[1]);
    return 1;
  }
  SFontTTF ttf(file, "");
  if (!ttf.isOK ())
  {
    fprintf (stderr, "ttfdump: bad font file '%s'\n", argv[1]);
    return 1;
  }
  fprintf (stdout, "# START ttfdump of %s\n", argv[1]);
  fprintf (stdout, "# Unicode GlypfIndex\n");
  unsigned int count = 0;
  SEncoder enc;
  for (unsigned int i=0; i<0x10000; i++)
  {
    SS_GlyphIndex ndx = ttf.findGlyph (i);
    if (ndx)
    {
      SV_UCS4 v; v.append (i);
      SString code = enc.encode (v);
      fprintf (stdout, "0x%04X 0x%04X\n", i, ndx);
      //fprintf (stdout, "0x%04X 0x%04X # %*.*s\n", i, i, SSARGS(code));
      count++;
    }
  }
  fprintf (stdout, "# END ttfdump of %s\n", argv[1]);
  fprintf (stderr, "ttfdump: %u glyphs found in BMP.\n", count);
  return 0;
}

static void
usage ()
{
  fprintf (stderr, "usage: ttfdump fontfile \n");
}
